@@ -40,12 +40,12 @@
 #include <tdeconfigdialog.h>
 
 #include <kchatdialog.h>
-#include <kgamechat.h>
-#include <dialogs/kgamedialog.h>
-#include <dialogs/kgamedialogconfig.h>
-#include <dialogs/kgameconnectdialog.h>
-#include <dialogs/kgameerrordialog.h>
-#include <dialogs/kgamedebugdialog.h>
+#include <kgame/kgamechat.h>
+#include <kgame/dialogs/kgamedialog.h>
+#include <kgame/dialogs/kgamedialogconfig.h>
+#include <kgame/dialogs/kgameconnectdialog.h>
+#include <kgame/dialogs/kgameerrordialog.h>
+#include <kgame/dialogs/kgamedebugdialog.h>
 
 // application specific includes
 #include "twin4.h"
